==> itk-4.13.2-py36_0.tar.bz2: Lib/site-packages/itk/Configuration/ITKPathConfig.py <==
depends = ('ITKPyBase', 'ITKImageFunction', 'ITKCommon', )
templates = (
  ('Path', 'itk::Path', 'itkPathDCID22', True, 'double, itk::ContinuousIndex< double,2 >, 2'),
  ('Path', 'itk::Path', 'itkPathDCID33', True, 'double, itk::ContinuousIndex< double,3 >, 3'),
  ('PolyLineParametricPath', 'itk::PolyLineParametricPath', 'itkPolyLineParametricPath2', True, '2'),
  ('PolyLineParametricPath', 'itk::PolyLineParametricPath', 'itkPolyLineParametricPath3', True, '3'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP2ISS2', True, 'itk::PolyLineParametricPath< 2 >, itk::Image< signed short,2 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP2IUC2', True, 'itk::PolyLineParametricPath< 2 >, itk::Image< unsigned char,2 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP2IUS2', True, 'itk::PolyLineParametricPath< 2 >, itk::Image< unsigned short,2 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP2IF2', True, 'itk::PolyLineParametricPath< 2 >, itk::Image< float,2 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP3ISS3', True, 'itk::PolyLineParametricPath< 3 >, itk::Image< signed short,3 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP3IUC3', True, 'itk::PolyLineParametricPath< 3 >, itk::Image< unsigned char,3 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP3IUS3', True, 'itk::PolyLineParametricPath< 3 >, itk::Image< unsigned short,3 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP3IF3', True, 'itk::PolyLineParametricPath< 3 >, itk::Image< float,3 >'),
  ('ParametricPath', 'itk::ParametricPath', 'itkParametricPath2', True, '2'),
  ('ParametricPath', 'itk::ParametricPath', 'itkParametricPath3', True, '3'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterISS2PLPP2', True, 'itk::Image< signed short,2 >, itk::PolyLineParametricPath< 2 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIUC2PLPP2', True, 'itk::Image< unsigned char,2 >, itk::PolyLineParametricPath< 2 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIUS2PLPP2', True, 'itk::Image< unsigned short,2 >, itk::PolyLineParametricPath< 2 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIF2PLPP2', True, 'itk::Image< float,2 >, itk::PolyLineParametricPath< 2 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterISS3PLPP3', True, 'itk::Image< signed short,3 >, itk::PolyLineParametricPath< 3 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIUC3PLPP3', True, 'itk::Image< unsigned char,3 >, itk::PolyLineParametricPath< 3 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIUS3PLPP3', True, 'itk::Image< unsigned short,3 >, itk::PolyLineParametricPath< 3 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIF3PLPP3', True, 'itk::Image< float,3 >, itk::PolyLineParametricPath< 3 >'),
  ('PathSource', 'itk::PathSource', 'itkPathSourcePLPP2', True, 'itk::PolyLineParametricPath< 2 >'),
  ('PathSource', 'itk::PathSource', 'itkPathSourcePLPP3', True, 'itk::PolyLineParametricPath< 3 >'),
)

==> itk-5.0.0-py37_0.tar.bz2: Lib/site-packages/itk/Configuration/ITKPathConfig.py <==
depends = ('ITKPyBase', 'ITKImageFunction', 'ITKCommon', )
templates = (
  ('Path', 'itk::Path', 'itkPathDCID22', True, 'double, itk::ContinuousIndex< double,2 >, 2'),
  ('Path', 'itk::Path', 'itkPathDCID33', True, 'double, itk::ContinuousIndex< double,3 >, 3'),
  ('PolyLineParametricPath', 'itk::PolyLineParametricPath', 'itkPolyLineParametricPath2', True, '2'),
  ('PolyLineParametricPath', 'itk::PolyLineParametricPath', 'itkPolyLineParametricPath3', True, '3'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP2ISS2', True, 'itk::PolyLineParametricPath< 2 >, itk::Image< signed short,2 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP2IUC2', True, 'itk::PolyLineParametricPath< 2 >, itk::Image< unsigned char,2 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP2IUS2', True, 'itk::PolyLineParametricPath< 2 >, itk::Image< unsigned short,2 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP2IF2', True, 'itk::PolyLineParametricPath< 2 >, itk::Image< float,2 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP3ISS3', True, 'itk::PolyLineParametricPath< 3 >, itk::Image< signed short,3 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP3IUC3', True, 'itk::PolyLineParametricPath< 3 >, itk::Image< unsigned char,3 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP3IUS3', True, 'itk::PolyLineParametricPath< 3 >, itk::Image< unsigned short,3 >'),
  ('PathToImageFilter', 'itk::PathToImageFilter', 'itkPathToImageFilterPLPP3IF3', True, 'itk::PolyLineParametricPath< 3 >, itk::Image< float,3 >'),
  ('ParametricPath', 'itk::ParametricPath', 'itkParametricPath2', True, '2'),
  ('ParametricPath', 'itk::ParametricPath', 'itkParametricPath3', True, '3'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterISS2PLPP2', True, 'itk::Image< signed short,2 >, itk::PolyLineParametricPath< 2 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIUC2PLPP2', True, 'itk::Image< unsigned char,2 >, itk::PolyLineParametricPath< 2 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIUS2PLPP2', True, 'itk::Image< unsigned short,2 >, itk::PolyLineParametricPath< 2 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIF2PLPP2', True, 'itk::Image< float,2 >, itk::PolyLineParametricPath< 2 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterISS3PLPP3', True, 'itk::Image< signed short,3 >, itk::PolyLineParametricPath< 3 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIUC3PLPP3', True, 'itk::Image< unsigned char,3 >, itk::PolyLineParametricPath< 3 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIUS3PLPP3', True, 'itk::Image< unsigned short,3 >, itk::PolyLineParametricPath< 3 >'),
  ('ImageToPathFilter', 'itk::ImageToPathFilter', 'itkImageToPathFilterIF3PLPP3', True, 'itk::Image< float,3 >, itk::PolyLineParametricPath< 3 >'),
  ('ContourExtractor2DImageFilter', 'itk::ContourExtractor2DImageFilter', 'itkContourExtractor2DImageFilterISS2', True, 'itk::Image< signed short,2 >'),
  ('ContourExtractor2DImageFilter', 'itk::ContourExtractor2DImageFilter', 'itkContourExtractor2DImageFilterIUC2', True, 'itk::Image< unsigned char,2 >'),
  ('ContourExtractor2DImageFilter', 'itk::ContourExtractor2DImageFilter', 'itkContourExtractor2DImageFilterIUS2', True, 'itk::Image< unsigned short,2 >'),
  ('ContourExtractor2DImageFilter', 'itk::ContourExtractor2DImageFilter', 'itkContourExtractor2DImageFilterIF2', True, 'itk::Image< float,2 >'),
  ('PathSource', 'itk::PathSource', 'itkPathSourcePLPP2', True, 'itk::PolyLineParametricPath< 2 >'),
  ('PathSource', 'itk::PathSource', 'itkPathSourcePLPP3', True, 'itk::PolyLineParametricPath< 3 >'),
)
snake_case_functions = ('contour_extractor2_d_image_filter', 'path_to_image_filter', 'image_to_path_filter', 'path_source', )
